==> vaw-layouts-0.1.0-1.tgz: package/src/store/index.js <==
import themeVariables from '../assets/styles/themes/index.js'
const layoutModes = ['ltr', 'lcr', 'ttb']

export default {
  state: {
    isCollapse: false,
    isFixedNavBar: true,
    layoutMode: 'ttb',
    device: 'pc',
    theme: 'blue-side',
    themeColor: 'theme-blue',
    themeVariables,
    userInfo: {},
    permissionRoutes: [],
    visitedView: [],
    actionItem: {
      showSearch: true,
      showMessage: true,
      showFullScreen: true,
      showRefresh: true
    }
  },
  init(config) {
    this.state = Object.assign(this.state, config)
  },
  randomLayouMode() {
    return layoutModes[Math.floor(Math.random() * layoutModes.length)]
  },
  toggleCollapse(newStatus) {
    this.state.isCollapse = newStatus
  },
  toggleFixedNavBar(newStatus) {
    this.state.isFixedNavBar = newStatus
  },
  changeLayoutMode(mode = 'ltr') {
    this.state.layoutMode = mode
  },
  changeDevice(device = 'pc') {
    this.state.device = device
  },
  changeTheme(theme = 'light') {
    this.state.theme = theme
  },
  isShowHeader() {
    return this.state.device === 'pc' && this.state.layoutMode === 'ttb'
  },
  getSplitTabs() {
    return this.state.permissionRoutes.filter(it => {
      return !it.hidden && it.children && it.children.length > 0
    })
  },
  initPermissionRoute(routes) {
    this.state.permissionRoutes = routes
  },
  isEmptyPermissionRoute() {
    return !this.state.permissionRoutes || this.state.permissionRoutes.length === 0
  },
  addVisitedView(route) {
    return new Promise(resolve => {
      if (!this.state.visitedView.find(it => it.fullPath === route.fullPath)) {
        this.state.visitedView.push(route)
      }
      resolve(route)
    })
  },
  removeVisitedView(route) {
    return new Promise(resolve => {
      this.state.visitedView.splice(this.state.visitedView.indexOf(route), 1)
      resolve(route)
    })
  },
  closeLeftVisitedView(selectRoute) {
    return new Promise(resolve => {
      const selectIndex = this.state.visitedView.indexOf(selectRoute)
      if (selectIndex !== -1) {
        this.state.visitedView = this.state.visitedView.filter((it, index) => {
          return (it.meta && it.meta.affix) || index >= selectIndex
        })
      }
      resolve()
    })
  },
  closeRightVisitedView(selectRoute) {
    return new Promise(resolve => {
      const selectIndex = this.state.visitedView.indexOf(selectRoute)
      if (selectIndex !== -1) {
        this.state.visitedView = this.state.visitedView.filter((it, index) => {
          return (it.meta && it.meta.affix) || index <= selectIndex
        })
      }
      resolve()
    })
  },

  closeAllVisitedView() {
    return new Promise(resolve => {
      this.state.visitedView = this.state.visitedView.filter((it, index) => {
        return (it.meta && it.meta.affix)
      })
      resolve()
    })
  }
}

==> vaw-layouts-0.1.0-4.tgz: package/src/store/index.js <==
import themeVariables from '../assets/styles/themes/index.js'
import { toggleThemeColorClass, toggleThemeClass } from '../utils'
const layoutModes = ['ltr', 'lcr', 'ttb']

export default {
  state: {
    isCollapse: false,
    isFixedNavBar: true,
    layoutMode: 'ltr',
    device: 'pc',
    theme: 'dark-side',
    themeColor: 'theme_color_blue',
    themeVariables,
    userInfo: {},
    permissionRoutes: [],
    visitedView: [],
    actionItem: {
      showSearch: true,
      showMessage: true,
      showFullScreen: true,
      showRefresh: true
    }
  },
  init(config) {
    this.state = Object.assign(this.state, config)
    toggleThemeColorClass(document.body, this.state.themeColor)
    toggleThemeClass(document.body, this.state.theme)
  },
  randomLayouMode() {
    return layoutModes[Math.floor(Math.random() * layoutModes.length)]
  },
  toggleCollapse(newStatus) {
    this.state.isCollapse = newStatus
  },
  toggleFixedNavBar(newStatus) {
    this.state.isFixedNavBar = newStatus
  },
  changeLayoutMode(mode = 'ltr') {
    this.state.layoutMode = mode
  },
  changeDevice(device = 'pc') {
    this.state.device = device
  },
  changeTheme(theme = 'light') {
    this.state.theme = theme
  },
  isShowHeader() {
    return this.state.device === 'pc' && this.state.layoutMode === 'ttb'
  },
  getSplitTabs() {
    return this.state.permissionRoutes.filter(it => {
      return !it.hidden && it.children && it.children.length > 0
    })
  },
  initPermissionRoute(routes) {
    this.state.permissionRoutes = routes
  },
  isEmptyPermissionRoute() {
    return !this.state.permissionRoutes || this.state.permissionRoutes.length === 0
  },
  addVisitedView(route) {
    return new Promise(resolve => {
      if (!this.state.visitedView.find(it => it.fullPath === route.fullPath)) {
        this.state.visitedView.push(route)
      }
      resolve(route)
    })
  },
  removeVisitedView(route) {
    return new Promise(resolve => {
      this.state.visitedView.splice(this.state.visitedView.indexOf(route), 1)
      resolve(route)
    })
  },
  closeLeftVisitedView(selectRoute) {
    return new Promise(resolve => {
      const selectIndex = this.state.visitedView.indexOf(selectRoute)
      if (selectIndex !== -1) {
        this.state.visitedView = this.state.visitedView.filter((it, index) => {
          return (it.meta && it.meta.affix) || index >= selectIndex
        })
      }
      resolve()
    })
  },
  closeRightVisitedView(selectRoute) {
    return new Promise(resolve => {
      const selectIndex = this.state.visitedView.indexOf(selectRoute)
      if (selectIndex !== -1) {
        this.state.visitedView = this.state.visitedView.filter((it, index) => {
          return (it.meta && it.meta.affix) || index <= selectIndex
        })
      }
      resolve()
    })
  },

  closeAllVisitedView() {
    return new Promise(resolve => {
      this.state.visitedView = this.state.visitedView.filter((it, index) => {
        return (it.meta && it.meta.affix)
      })
      resolve()
    })
  }
}
